import pandas as pd
from pathlib import Path

def is_ensembl(col):
    """
    This is a ontology checker function which checks if the input given is ensembl ontology or not using pattern matching.

    Args:
        col (str): string to be checked 

    Returns:
        bool:True if the string is ensembl ontology and False for rest
    """
    try:
        col=col.strip()
        if col[:3] =='ENS' and col[-11:].isnumeric():
            return True
        else:
            return False
    except Exception:
        return False

def is_gene_ass(col):
    """
    This is a ontology checker function which checks if the input given is gene_assignment ontology or not using pattern matching.

    Args:
        col (str): string to be checked 

    Returns:
        bool:True if the string is gene_assignment ontology and False for rest
    """
    try:
        if "//" in col:
            x=col.split('//')
            if is_entrez(x[4].strip()):
                return True
        return False
    except Exception:
        return False


def is_entrez(col):
    """
    This is a ontology checker function which checks if the input given is entrez ontology or not by checking if the string is purely numbers.

    Args:
        col (str): string to be checked 

    Returns:
        bool:True if the string is entrez ontology and False for rest
    """
    try:
        col=str(col)
        col=col.strip()
        if col and not col.isalpha():
            a=float(col)
            return True
        else:
            return False
    except Exception:
        return False

def is_genbank(col):
    """
    This is a ontology checker function which checks if the input given is genbank ontology or not using pattern matching.

    Args:
        col (str): string to be checked 

    Returns:
        bool:True if the string is genbank ontology and False for rest
    """
    try:
        col=col.strip()
        if col[2]=='_' and is_entrez(col[3:]) and col[:2].isalpha():
            return True
        else:
            return False
    except Exception:
        return False

def is_genbank_gblist(col):
    """
    This is a ontology checker function which checks if the input given is genbank_gblist ontology or not using pattern matching.

    Args:
        col (str): string to be checked 

    Returns:
        bool:True if the string is genbank_gblist ontology and False for rest
    """
    try:
        col=col.strip()
        if '.' not in col:
            if (col[:2].isalpha() and col[2:9].isnumeric() and col[-1].isnumeric()) or (col[0].isalpha() and col[1:7].isnumeric() and col[-1].isnumeric()):
                return True
        return False
    except Exception:
        return False

def is_assoc_gene(col):
    """
    This is a ontology checker function which checks if the input given is Associated Gene ontology or not using pattern matching.

    Args:
        col (str): string to be checked 

    Returns:
        bool:True if the string is Associated Gene ontology and False for rest
    """
    try:
        if "//" in col:
            x=col.split('//')
            if is_entrez(x[5].strip()):
                return True
        return False
    except Exception:
        return False

def is_symbol(col):
    """
    This is a ontology checker function which checks if the input given is symbol ontology or not using a conversion list if the symbol is in our known file.

    Args:
        col (str): string to be checked 

    Returns:
        bool:True if the string is symbol ontology and False for rest
    """
    try:
        dic=pd.read_csv(str(Path(__file__).parent) +"/annotation_files/symbol-to-entrez.tsv",sep='\t')
        lst=list(dic.iloc[:,-1])
        if col.upper() in lst:
            return True
        return False
    except Exception:
        return False